@@ -41,7 +41,7 @@ class ToTensor:
         self.keys = keys
 
     def __call__(self, results):
-        """Performs the ToTensor formating.
+        """Performs the ToTensor formatting.
 
         Args:
             results (dict): The resulting dict to be modified and passed
@@ -96,7 +96,7 @@ class ToDataContainer:
         self.fields = fields
 
     def __call__(self, results):
-        """Performs the ToDataContainer formating.
+        """Performs the ToDataContainer formatting.
 
         Args:
             results (dict): The resulting dict to be modified and passed
@@ -128,7 +128,7 @@ class ImageToTensor:
         self.keys = keys
 
     def __call__(self, results):
-        """Performs the ImageToTensor formating.
+        """Performs the ImageToTensor formatting.
 
         Args:
             results (dict): The resulting dict to be modified and passed
@@ -185,7 +185,7 @@ class Collect:
 
     Args:
         keys (Sequence[str]): Required keys to be collected.
-        meta_name (str): The name of the key that contains meta infomation.
+        meta_name (str): The name of the key that contains meta information.
             This key is always populated. Default: "img_metas".
         meta_keys (Sequence[str]): Keys that are collected under meta_name.
             The contents of the ``meta_name`` dictionary depends on
@@ -222,7 +222,7 @@ class Collect:
         self.nested = nested
 
     def __call__(self, results):
-        """Performs the Collect formating.
+        """Performs the Collect formatting.
 
         Args:
             results (dict): The resulting dict to be modified and passed
@@ -271,7 +271,7 @@ class FormatShape:
                 f'The input format {self.input_format} is invalid.')
 
     def __call__(self, results):
-        """Performs the FormatShape formating.
+        """Performs the FormatShape formatting.
 
         Args:
             results (dict): The resulting dict to be modified and passed
@@ -321,6 +321,7 @@ class FormatShape:
             # M = N_clips x L
             imgs = np.transpose(imgs, (0, 1, 4, 2, 3))
             # P x M x C x H x W
+
         if self.collapse:
             assert imgs.shape[0] == 1
             imgs = imgs.squeeze(0)
@@ -371,3 +372,53 @@ class FormatAudioShape:
         repr_str = self.__class__.__name__
         repr_str += f"(input_format='{self.input_format}')"
         return repr_str
+
+
+@PIPELINES.register_module()
+class FormatGCNInput:
+    """Format final skeleton shape to the given input_format.
+
+    Required keys are "keypoint" and "keypoint_score", added or modified
+    keys are "keypoint" and "input_shape".
+
+    Args:
+        input_format (str): Define the final skeleton format.
+    """
+
+    def __init__(self, input_format, num_person=2):
+        self.input_format = input_format
+        if self.input_format not in ['NCTVM']:
+            raise ValueError(
+                f'The input format {self.input_format} is invalid.')
+        self.num_person = num_person
+
+    def __call__(self, results):
+        """Performs the FormatShape formatting.
+
+        Args:
+            results (dict): The resulting dict to be modified and passed
+                to the next transform in pipeline.
+        """
+        keypoint = results['keypoint']
+        keypoint_confidence = results['keypoint_score']
+        keypoint_confidence = np.expand_dims(keypoint_confidence, -1)
+        keypoint_3d = np.concatenate((keypoint, keypoint_confidence), axis=-1)
+        keypoint_3d = np.transpose(keypoint_3d,
+                                   (3, 1, 2, 0))  # M T V C -> C T V M
+
+        if keypoint_3d.shape[-1] < self.num_person:
+            pad_dim = self.num_person - keypoint_3d.shape[-1]
+            pad = np.zeros(
+                keypoint_3d.shape[:-1] + (pad_dim, ), dtype=keypoint_3d.dtype)
+            keypoint_3d = np.concatenate((keypoint_3d, pad), axis=-1)
+        elif keypoint_3d.shape[-1] > self.num_person:
+            keypoint_3d = keypoint_3d[:, :, :, :self.num_person]
+
+        results['keypoint'] = keypoint_3d
+        results['input_shape'] = keypoint_3d.shape
+        return results
+
+    def __repr__(self):
+        repr_str = self.__class__.__name__
+        repr_str += f"(input_format='{self.input_format}')"
+        return repr_str
